@@ -3,8 +3,8 @@ package tree_sitter_query_test
 import (
 	"testing"
 
-	tree_sitter "github.com/smacker/go-tree-sitter"
-	"github.com/tree-sitter-grammars/tree-sitter-query"
+	tree_sitter "github.com/tree-sitter/go-tree-sitter"
+	tree_sitter_query "github.com/tree-sitter-grammars/tree-sitter-query/bindings/go"
 )
 
 func TestCanLoadGrammar(t *testing.T) {
