@@ -7,7 +7,7 @@ typedef struct TSLanguage TSLanguage;
 extern "C" {
 #endif
 
-extern TSLanguage *tree_sitter_query();
+const TSLanguage *tree_sitter_query(void);
 
 #ifdef __cplusplus
 }
